AuDoLab.subclasses
==========================

AuDoLab.subclasses.abstractscraper
-----------------------------------------

.. automodule:: AuDoLab.subclasses.abstractscraper
   :members:
   :undoc-members:
   :show-inheritance:

AuDoLab.subclasses.abstractscraper\_old
----------------------------------------------

.. automodule:: AuDoLab.subclasses.abstractscraper_old
   :members:
   :undoc-members:
   :show-inheritance:

AuDoLab.subclasses.lda
-----------------------------

.. automodule:: AuDoLab.subclasses.lda
   :members:
   :undoc-members:
   :show-inheritance:

AuDoLab.subclasses.one\_class\_svm
-----------------------------------------

.. automodule:: AuDoLab.subclasses.one_class_svm
   :members:
   :undoc-members:
   :show-inheritance:

AuDoLab.subclasses.preprocessing
---------------------------------------

.. automodule:: AuDoLab.subclasses.preprocessing
   :members:
   :undoc-members:
   :show-inheritance:

AuDoLab.subclasses.tf\_idf 
---------------------------------

.. automodule:: AuDoLab.subclasses.tf_idf
   :members:
   :undoc-members:
   :show-inheritance:
